@@ -19,5 +19,8 @@ Model::insert(const string& key, const vector<mdreal>& values) {
   /* Insert a new data point. */
   mdsize rank = (p->points).size();
   p->points[key] = Point(rank, values);
+
+  /* Reset training state. */
+  (p->state).clear();
   return "";
 }
