@@ -11,9 +11,9 @@
 #include <cctype>
 #include <cmath>
 #include <ctime>
+#include <random>
 #include <string>
 #include <vector>
-#include <random>
 #include <algorithm>
 #include <Rcpp.h>
 #include "medusa.h"
@@ -22,6 +22,8 @@
 #include "punos.h"
 #include "koho.h"
 
+#define SIGMA_nro 1.0
+
 using namespace std;
 using namespace Rcpp;
 using namespace medusa;
@@ -36,11 +38,12 @@ using namespace koho;
 namespace nro {
   extern vector<vector<mdreal> > matrix2reals(const SEXP&, const mdreal);
   extern NumericMatrix reals2matrix(const vector<vector<mdreal> >&);
-  extern punos::Topology reals2topology(const vector<vector<mdreal> >&);
   extern NumericVector reals2vector(const vector<mdreal>&);
   extern vector<mdreal> vector2reals(const SEXP&);
   extern vector<mdsize> vector2sizes(const SEXP&);
-};
+  extern punos::Topology reals2topology(const vector<vector<mdreal> >&,
+					const mdreal);
+}
 
 using namespace nro;
 
